aboutsummaryrefslogtreecommitdiffstats
path: root/uitest
diff options
context:
space:
mode:
authorHenri Sara <hesara@vaadin.com>2014-08-04 08:23:01 +0300
committerVaadin Code Review <review@vaadin.com>2014-08-05 06:26:03 +0000
commit295f116b91789bc0ff5422e54f2df4e59eb53294 (patch)
tree88b135cd2974fec1d6e2faa1d01529bf4d3f01c1 /uitest
parentaa25700c8aa2ae974e1c9e3ce3230335d8309814 (diff)
downloadvaadin-framework-295f116b91789bc0ff5422e54f2df4e59eb53294.tar.gz
vaadin-framework-295f116b91789bc0ff5422e54f2df4e59eb53294.zip
Increase TB3 socket timeout to 30 min (#14352)
This increases the timeout from 15 to 30 minutes to avoid occasional timeouts at times of test cluster congestion. The timeout was originally reduced for #14298. Change-Id: I59e8ad892356c94954d0d20884319de653704ca4
Diffstat (limited to 'uitest')
-rw-r--r--uitest/src/com/vaadin/tests/tb3/TB3Runner.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/uitest/src/com/vaadin/tests/tb3/TB3Runner.java b/uitest/src/com/vaadin/tests/tb3/TB3Runner.java
index 4241b9fa6c..0d540644bf 100644
--- a/uitest/src/com/vaadin/tests/tb3/TB3Runner.java
+++ b/uitest/src/com/vaadin/tests/tb3/TB3Runner.java
@@ -57,10 +57,10 @@ public class TB3Runner extends BlockJUnit4ClassRunner {
/**
* Socket timeout for HTTP connections to the grid hub. The connection is
* closed after 15 minutes of inactivity to avoid builds hanging for up to
* three hours per connection if the test client crashes/hangs.
*/
- private static final int SOCKET_TIMEOUT = 15 * 60 * 1000;
+ private static final int SOCKET_TIMEOUT = 30 * 60 * 1000;
/**
* This is the total limit of actual JUnit test instances run in parallel
@@ -57,10 +57,10 @@ public class TB3Runner extends BlockJUnit4ClassRunner {
/**
* Socket timeout for HTTP connections to the grid hub. The connection is
- * closed after 15 minutes of inactivity to avoid builds hanging for up to
+ * closed after 30 minutes of inactivity to avoid builds hanging for up to
* three hours per connection if the test client crashes/hangs.
*/